@@ -5,17 +5,14 @@ import open3d as o3d
 import pandas as pd
 from laspy.file import File
 
-_FIELDS = ['x', 'y', 'z', 'i', 'd']
+_FIELDS = ["x", "y", "z", "i", "d"]
 
 
 class Importer:
-    """Points importer/helper
+    """Points importer/helper"""
 
-    """
     class Base(metaclass=ABCMeta):
-        """Abstract importer class to be inherited for data type specific implementation
-
-        """
+        """Abstract importer class to be inherited for data type specific implementation"""
 
         def __init__(self, fp: str) -> None:
             """Constructor to be called for preparing filepaths
@@ -24,9 +21,7 @@ class Importer:
             :type fp: str
             """
             self._filepath: str = fp
-            self._data: pd.DataFrame = pd.DataFrame(
-                columns=_FIELDS
-            )
+            self._data: pd.DataFrame = pd.DataFrame(columns=_FIELDS)
 
         def load(self, **kwargs) -> None:
             self._load(**kwargs)
@@ -57,10 +52,7 @@ class Importer:
             self._data = pd.read_csv(self._filepath, **kwargs)
             c_count = len(self._data.columns)
             if c_count > 5:  # Remove columns exceeding count of FIELDS
-                self._data = self._data.drop(
-                    self._data.columns[5:],
-                    axis=1
-                )
+                self._data = self._data.drop(self._data.columns[5:], axis=1)
                 c_count = 5
 
             self._data.columns = _FIELDS[:c_count]
@@ -79,29 +71,22 @@ class Importer:
             self._data = self._data[exists]
 
     class PCD(Base):
-        """Uses open3d library to read pcd files, expects `[x, y, z]`, dismisses other columns.
-
-        """
+        """Uses open3d library to read pcd files, expects `[x, y, z]`, dismisses other columns."""
 
         def _load(self, **kwargs):
             self._data = pd.DataFrame(
                 np.asarray(o3d.io.read_point_cloud(self._filepath).points)[:, :3],
-                columns=_FIELDS[:3]
+                columns=_FIELDS[:3],
             )
 
     class LAS(Base):
-        """Uses Laspy library to read .las file and expects properties `x`, `y`, `z`, `intensity` to be present.
-
-        """
+        """Uses Laspy library to read .las file and expects properties `x`, `y`, `z`, `intensity` to be present."""
 
         def _load(self, **kwargs):
-            las_file = File(self._filepath, mode='r')
+            las_file = File(self._filepath, mode="r")
             self._data = pd.DataFrame(
-                np.column_stack([
-                    las_file.x,
-                    las_file.y,
-                    las_file.z,
-                    las_file.intensity
-                ]),
-                columns=['x', 'y', 'z', 'i']
+                np.column_stack(
+                    [las_file.x, las_file.y, las_file.z, las_file.intensity]
+                ),
+                columns=["x", "y", "z", "i"],
             )
