@@ -140,12 +140,17 @@ class LidarFrame:
         if points.ndim == 1:
             points = np.array([points])
         if points.shape[1] == 3:
-            points = np.hstack([points, np.ones((points.shape[0], 1)) * intensity])
+            points = np.hstack(
+                [points, np.ones((points.shape[0], 1)) * intensity])
+        if points.shape[1] == 4:
+            if sensor_id != 0:
+                points = np.hstack(
+                    [points, np.ones((points.shape[0], 1)) * sensor_id])
+            else:
+                points = np.hstack([points, np.zeros((points.shape[0], 1))])
         if transform is not None:
             points = transform.apply(points)
 
-        points = np.hstack([points, np.ones((points.shape[0], 1)) * sensor_id])
-
         self.points = np.vstack([self.points, points])
 
     def add_colors(self, colors: np.ndarray):
@@ -182,7 +187,8 @@ class LidarFrame:
         :type device: int
 
         """
-        x_line = np.array([np.array([length * k / 100, 0, 0]) for k in range(0, 100)])
+        x_line = np.array([np.array([length * k / 100, 0, 0])
+                          for k in range(0, 100)])
         for camera in self.cameras:
             self.add_points(
                 x_line, transform=camera.world_transform, intensity=intensity
@@ -247,7 +253,8 @@ class LidarFrame:
         imgObj = fig.add_subplot(gs[0, :])
         imgObj.imshow(
             self.cameras[camera_id].get_projected_image(
-                self.get_image(camera_id), self.points, self.transform, "depth", 1
+                self.get_image(
+                    camera_id), self.points, self.transform, "depth", 1
             )
         )
 
@@ -289,7 +296,8 @@ class LidarFrame:
 
         def update(val):
             self.cameras[camera_id].calibrate(
-                K=np.array([[fx.val, 0, cx.val], [0, fy.val, cy.val], [0, 0, 1]]),
+                K=np.array(
+                    [[fx.val, 0, cx.val], [0, fy.val, cy.val], [0, 0, 1]]),
                 pose=Transform.from_Rt(
                     Quaternion(qw.val, qx.val, qy.val, qz.val).rotation_matrix,
                     [x.val, y.val, z.val],
@@ -312,7 +320,8 @@ class LidarFrame:
 
             imgObj.imshow(
                 self.cameras[camera_id].get_projected_image(
-                    self.get_image(camera_id), self.points, self.transform, "depth", 1
+                    self.get_image(
+                        camera_id), self.points, self.transform, "depth", 1
                 )
             )
             fig.canvas.draw_idle()
@@ -382,7 +391,8 @@ class LidarFrame:
 
             image_url = "%s/image-%s-%s.jpg" % (base_url, camera.id, self.id)
             if not s3_upload:
-                image_url = self.images[camera.id].scale_file_upload(project_name)
+                image_url = self.images[camera.id].scale_file_upload(
+                    project_name)
 
             result = dict(
                 position=format_point(wct.position),
@@ -473,7 +483,8 @@ class LidarFrame:
 
         # Save images
         for camera_id, image in self.images.items():
-            image.save(os.path.join(path, "image-%s-%s.jpg" % (camera_id, self.id)))
+            image.save(os.path.join(path, "image-%s-%s.jpg" %
+                       (camera_id, self.id)))
 
     def s3_upload(self, bucket: str, path: str):
         """Save frame in S3
@@ -526,10 +537,13 @@ class LidarFrame:
 
         pcd = pcd.voxel_down_sample(voxel_size_mm / 1000)
 
-        positions, intensities = np.asarray(pcd.points), np.asarray(pcd.normals)[:, 0]
-        points = np.hstack([positions, intensities.reshape(intensities.shape[0], 1)])
+        positions, intensities = np.asarray(
+            pcd.points), np.asarray(pcd.normals)[:, 0]
+        points = np.hstack(
+            [positions, intensities.reshape(intensities.shape[0], 1)])
 
-        self.points = np.hstack([points, np.zeros((points.shape[0], 1), dtype=float)])
+        self.points = np.hstack(
+            [points, np.zeros((points.shape[0], 1), dtype=float)])
         self.colors = np.asarray(pcd.colors)
 
     def __repr__(self):
